==> icecat-2.0.0.11-g1.tar.bz2: icecat-2.0.0.11-g1/extensions/xforms/nsXFormsActionElement.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla XForms support.
 *
 * The Initial Developer of the Original Code is
 * Olli Pettay.
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Olli Pettay <Olli.Pettay@helsinki.fi> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef nsXFormsActionElement_h_
#define nsXFormsActionElement_h_

#include "nsIXFormsActionElement.h"
#include "nsXFormsActionModuleBase.h"
#include "nsDataHashtable.h"
#include "nsXFormsControlStub.h"

class nsIXTFBindableElementWrapper;

class nsXFormsActionElement : public nsXFormsBindableControlStub,
                              public nsIXFormsActionElement,
                              public nsIXFormsActionModuleElement,
                              public nsIDOMEventListener
{
public:

  NS_DECL_ISUPPORTS_INHERITED
  NS_DECL_NSIDOMEVENTLISTENER
  NS_DECL_NSIXFORMSACTIONELEMENT
  NS_DECL_NSIXFORMSACTIONMODULEELEMENT
  NS_IMETHOD OnCreated(nsIXTFBindableElementWrapper* aWrapper);
  NS_IMETHOD OnDestroyed();
  NS_IMETHOD WillChangeDocument(nsIDOMDocument *aNewDocument);
  NS_IMETHOD DocumentChanged(nsIDOMDocument *aNewDocument);
  NS_IMETHOD WillChangeParent(nsIDOMElement *aNewParent);
  NS_IMETHOD ParentChanged(nsIDOMElement *aNewParent);

private:
  nsCOMPtr<nsIXFormsActionElement>              mParentAction;
  nsDataHashtable<nsISupportsHashKey, PRUint32> mDeferredUpdates;
};

#endif

==> icecat-3.0.1-g1.tar.bz2: icecat-3.0.1-g1/extensions/xforms/nsXFormsActionElement.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla XForms support.
 *
 * The Initial Developer of the Original Code is
 * Olli Pettay.
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Olli Pettay <Olli.Pettay@helsinki.fi> (original author)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef nsXFormsActionElement_h_
#define nsXFormsActionElement_h_

#include "nsIXFormsActionElement.h"
#include "nsXFormsActionModuleBase.h"
#include "nsDataHashtable.h"
#include "nsXFormsStubElement.h"

class nsIXTFElementWrapper;

class nsXFormsActionElement : public nsXFormsStubElement,
                              public nsIXFormsActionElement,
                              public nsIXFormsActionModuleElement,
                              public nsIDOMEventListener,
                              public nsXFormsActionModuleHelper
{
public:
  nsXFormsActionElement();
  NS_DECL_ISUPPORTS_INHERITED
  NS_DECL_NSIDOMEVENTLISTENER
  NS_DECL_NSIXFORMSACTIONELEMENT
  NS_DECL_NSIXFORMSACTIONMODULEELEMENT
  NS_IMETHOD OnCreated(nsIXTFElementWrapper *aWrapper);
  NS_IMETHOD OnDestroyed();
  NS_IMETHOD WillChangeDocument(nsIDOMDocument *aNewDocument);
  NS_IMETHOD DocumentChanged(nsIDOMDocument *aNewDocument);
  NS_IMETHOD WillChangeParent(nsIDOMElement *aNewParent);
  NS_IMETHOD ParentChanged(nsIDOMElement *aNewParent);

  virtual nsIDOMElement* GetElement() { return mElement; }
  virtual nsresult HandleSingleAction(nsIDOMEvent* aEvent,
                                      nsIXFormsActionElement* aParentAction);
private:
  nsIDOMElement*                                mElement;
  nsCOMPtr<nsIXFormsActionElement>              mParentAction;
  nsDataHashtable<nsISupportsHashKey, PRUint32> mDeferredUpdates;
};


#endif
